<!--
Thank you for taking the time to report an issue! We're glad to have you involved with Ruff.

If you're filing a bug report, please consider including the following information:

* A minimal code snippet that reproduces the bug.
* The current Ruff and LSP settings (any relevant sections from your `pyproject.toml`).
* The current Ruff and LSP versions (`ruff --version`).
-->
